@@ -31,7 +31,7 @@ import textwrap
 import tokenize
 
 
-__version__ = '0.5'
+__version__ = '0.5.1'
 
 
 try:
@@ -212,12 +212,9 @@ def reindent(text, indentation):
     if '\t' not in indentation:
         text = text.expandtabs(len(indentation))
 
-    # Ignore the first line, which is a special case.
-    split_lines = text.splitlines()
-    text = textwrap.dedent('\n'.join(split_lines[1:]))
+    text = textwrap.dedent(text)
 
     return '\n'.join(
-        [indentation + split_lines[0].strip()] +
         [(indentation + line).rstrip()
          for line in text.splitlines()]).rstrip() + '\n'
 
@@ -250,7 +247,7 @@ def split_summary_and_description(contents):
         for index, line in enumerate(split):
             if not line.strip():
                 return ('\n'.join(split[:index]).strip(),
-                        '\n'.join(split[index:]).strip())
+                        '\n'.join(split[index:]).rstrip())
 
     # Break on first sentence.
     for punctuation in '.?!:':
@@ -259,7 +256,7 @@ def split_summary_and_description(contents):
                          maxsplit=1)
         if len(split) == 2:
             return (split[0].strip() + punctuation,
-                    split[1].strip())
+                    split[1].rstrip())
 
     # Break on first bullet-list-like text.
     for token in ['    @',
@@ -269,7 +266,7 @@ def split_summary_and_description(contents):
         if len(split) == 2:
             return (split[0].strip(), (token + split[1]).strip())
 
-    return (split[0].strip(), '')
+    return (split[0], '\n'.join(split[1:]))
 
 
 def strip_docstring(docstring):
@@ -313,6 +310,9 @@ def wrap_description(text, indentation, wrap_length):
     and bulleted lists alone.
 
     """
+    # Do not modify leading indentation unnecessarily.
+    text = text.lstrip('\n')
+
     # Do not modify doctests at all.
     if '>>>' in text:
         return text
